==> avidemux_2.0.28.orig.tar.gz: avidemux-2.0.28/avidemux/oplug_avi/op_savecopy.h <==
/***************************************************************************
                          op_savecopy.h  -  description
                             -------------------
    begin                : Fri May 3 2002
    copyright            : (C) 2002 by mean
    email                : fixounet@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 #ifndef __AVI_SAVECPY__
 #define   __AVI_SAVECPY__

 class GenericAviSaveCopy : public   GenericAviSave
 {
     protected :
			
		          virtual uint8_t 	setupVideo( char *name  );
                          virtual uint8_t 	writeVideoChunk(uint32_t frame );

     public:
     						GenericAviSaveCopy()  :     GenericAviSave()
										{
										};	
                          virtual ~GenericAviSaveCopy();
   };

 class GenericAviSaveCopyDualAudio : public   GenericAviSaveCopy
 {
     protected :

			uint32_t		two_audio_frame_full;
                 	uint32_t		two_audio_frame_left;
                    	uint32_t 		two_pcm_audio_frame;
                        int32_t  		two_audio_stock;
                        char				*_trackname;



		                   virtual uint8_t setupAudio( void);
                        	 virtual uint8_t writeAudioChunk(void );
				 //virtual uint8_t setupVideo (char *name);
     public:
                                     GenericAviSaveCopyDualAudio(AVDMGenericAudioStream	*track);
                          virtual ~GenericAviSaveCopyDualAudio();
   };



  #endif

==> avidemux_2.0.36.orig.tar.gz: avidemux-2.0.36/avidemux/oplug_avi/op_savecopy.h <==
/***************************************************************************
                          op_savecopy.h  -  description
                             -------------------
    begin                : Fri May 3 2002
    copyright            : (C) 2002 by mean
    email                : fixounet@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 #ifndef __AVI_SAVECPY__
 #define   __AVI_SAVECPY__

 class GenericAviSaveCopy : public   GenericAviSave
 {
     protected :
			
		          virtual uint8_t 	setupVideo( char *name  );
                          virtual uint8_t 	writeVideoChunk(uint32_t frame );
			  	  uint8_t	_needUserDataUpdate;

     public:
     						GenericAviSaveCopy()  :     GenericAviSave()
										{
											_needUserDataUpdate=0;
										};
						GenericAviSaveCopy(uint8_t pack)  :     GenericAviSave()
										{
											_needUserDataUpdate=pack;
										};	
               //           virtual ~GenericAviSaveCopy();
   };

 class GenericAviSaveCopyDualAudio : public   GenericAviSaveCopy
 {
     protected :

			
                        char				*_trackname;
			uint32_t			_audioCurrent2;


		                   virtual uint8_t setupAudio( void);
                        	 virtual uint8_t writeAudioChunk(uint32_t frame );
				 //virtual uint8_t setupVideo (char *name);
     public:
                                     GenericAviSaveCopyDualAudio(AVDMGenericAudioStream	*track);
                          //virtual ~GenericAviSaveCopyDualAudio();
   };



  #endif
